@@ -2,6 +2,7 @@ import builtins
 import os
 import tempfile
 import json
+import sys
 import zipfile
 import h5py
 from datetime import datetime
@@ -63,6 +64,7 @@ class MyHDFFile(h5py.File):
         self.local_path = args[0]
         # noinspection PyUnresolvedReferences,PyProtectedMember
         if isinstance(self.local_path, tempfile._TemporaryFileWrapper):
+            # noinspection PyUnresolvedReferences
             h5py.File.__init__(self, args[0].name, *args[1:], **kwargs)
         else:
             h5py.File.__init__(self, *args, **kwargs)
@@ -72,7 +74,9 @@ class MyHDFFile(h5py.File):
         a 'with' statement."""
         h5py.File.__exit__(self, *args)
         if self.remote_file is not None:
+            # noinspection PyUnresolvedReferences
             TransparentPath(self.local_path.name, fs="local").put(self.remote_file)
+            # noinspection PyUnresolvedReferences
             self.local_path.close()
 
 
@@ -115,6 +119,13 @@ class Myzipfile(zipfileclass):
 zipfile.ZipFile = Myzipfile
 
 
+def check_dask():
+    if "dask" not in sys.modules:
+        raise ImportError("Daks does not seem to be installed. You will not be able to use Dask DataFrames"
+                          " in TransparentPath.\n You can change that by running"
+                          " 'pip install transparentpath[dask]'.")
+
+
 def mysmallisinstance(obj1: Any, obj2) -> bool:
     """Will return True when testing whether a TransparentPath is a str (required to use open(TransparentPath()))
     or a TransparentPath, and False in every other cases (even pathlib.Path). """
@@ -286,14 +297,14 @@ def apply_index_and_date(
         df.index = df.index.rename(None)
     if parse_dates is not None:
         if isinstance(df, dd.DataFrame):
-            df.index = df.to_datetime(df.index)
+            df.index = dd.to_datetime(df.index)
         else:
             df.index = pd.to_datetime(df.index)
     return df
 
 
 def check_kwargs(method: Callable, kwargs: dict):
-    """Takes as argument a method and some kwargs. Will like in the method signature et return in two separate dict
+    """Takes as argument a method and some kwargs. Will look in the method signature and return in two separate dict
     the kwargs that are in the signature and those that are not.
 
     If the method does not return any signature or if it explicitely accepts **kwargs, does not do anything
@@ -665,7 +676,13 @@ class TransparentPath(os.PathLike):  # noqa : F811
                         )
                 else:
                     bucket = bucket_from_path
-                if TransparentPath.bucket is None:
+                if TransparentPath.bucket is not None:
+                    if TransparentPath.bucket != bucket_from_path:
+                        raise ValueError(
+                            f"Bucket name {bucket_from_path} was found in your path name, but it does "
+                            f"not match the bucket name you specified for TransparentPath: {TransparentPath.bucket}"
+                        )
+                else:
                     TransparentPath.bucket = bucket_from_path
                 path = str(path).replace("gs://", "").replace(bucket_from_path, "")
                 if path.startswith("/"):
@@ -712,7 +729,8 @@ class TransparentPath(os.PathLike):  # noqa : F811
 
             # Remove occurences of nas_dir at beginning of path, if any
             if self.nas_dir is not None and (
-                    str(self.__path).startswith(os.path.abspath(self.nas_dir) + os.sep) or str(self.__path) == self.nas_dir
+                    str(self.__path).startswith(os.path.abspath(self.nas_dir) + os.sep)
+                    or str(self.__path) == self.nas_dir
             ):
                 self.__path = self.__path.relative_to(self.nas_dir)
 
@@ -729,7 +747,7 @@ class TransparentPath(os.PathLike):  # noqa : F811
             else:
                 self.__path = Path(self.bucket) / self.__path
             if len(self.__path.parts) > 1 and self.bucket in self.__path.parts[1:]:
-                raise ValueError("You should never use you bucket name as a directory or file name.")
+                raise ValueError("You should never use your bucket name as a directory or file name.")
 
         if nocheck is False:
             self.check_multiplicity()
@@ -885,7 +903,7 @@ class TransparentPath(os.PathLike):  # noqa : F811
 
         if obj_name in TransparentPath._attributes:
             raise AttributeError(
-                f"Attribute {obj_name} is expected to belong to TransparentPath but is not found. Something somehaw "
+                f"Attribute {obj_name} is expected to belong to TransparentPath but is not found. Something somehow "
                 f"tried to access this attribute before a proper call to __init__. "
             )
 
@@ -1390,9 +1408,11 @@ class TransparentPath(os.PathLike):  # noqa : F811
         """
         self.update_cache()
         thepath = self / path
+        # noinspection PyUnresolvedReferences
         if not thepath.exists():
             raise FileNotFoundError(f"Could not find location {self}")
 
+        # noinspection PyUnresolvedReferences
         if thepath.is_file():
             raise NotADirectoryError("Can not ls on a file!")
 
@@ -1442,13 +1462,17 @@ class TransparentPath(os.PathLike):  # noqa : F811
         newpath = self / path
 
         if self.fs_kind == "local":
+            # noinspection PyUnresolvedReferences
             if len(newpath.parts) == 0:
                 return TransparentPath(newpath, fs=self.fs_kind)
+            # noinspection PyUnresolvedReferences
             if newpath.parts[0] == "..":
                 raise ValueError("The first part of a path can not be '..'")
         else:
+            # noinspection PyUnresolvedReferences
             if len(newpath.parts) == 1:  # On gcs, first part is bucket
                 return TransparentPath(newpath, fs=self.fs_kind)
+            # noinspection PyUnresolvedReferences
             if newpath.parts[1] == "..":
                 raise ValueError("Trying to access a path before bucket")
 
@@ -1546,6 +1570,7 @@ class TransparentPath(os.PathLike):  # noqa : F811
             if self.suffix != ".csv" and self.suffix != ".parquet" and not self.is_file():
                 raise FileNotFoundError(f"Could not find file {self}")
             else:
+                # noinspection PyUnresolvedReferences
                 if (
                     not self.is_file()
                     and not self.is_dir(exist=True)
@@ -1585,6 +1610,7 @@ class TransparentPath(os.PathLike):  # noqa : F811
         # noinspection PyTypeChecker,PyUnresolvedReferences
         try:
             if use_dask:
+                check_dask()
                 if self.is_file():
                     to_use = self
                 else:
@@ -1612,6 +1638,7 @@ class TransparentPath(os.PathLike):  # noqa : F811
         index_col, parse_dates, kwargs = get_index_and_date_from_kwargs(**kwargs)
 
         if use_dask:
+            check_dask()
             # Dask's read_parquet supports remote files, pandas does not
             if self.is_file():
                 to_use = self
@@ -1699,6 +1726,7 @@ class TransparentPath(os.PathLike):  # noqa : F811
             raise ValueError("If using read_hdf5, mode must contain 'r'")
 
         if use_dask:
+            check_dask()
             if len(set_names) == 0:
                 raise ValueError(
                     "If using Dask, you must specify the dataset name to extract using set_names='aname'"
@@ -1741,6 +1769,7 @@ class TransparentPath(os.PathLike):  # noqa : F811
         try:
             if self.fs_kind == "local":
                 if use_dask:
+                    check_dask()
                     parts = delayed(pd.read_excel)(self, **kwargs)
                     return dd.from_delayed(parts)
                 return pd.read_excel(self, **kwargs)
@@ -1749,6 +1778,7 @@ class TransparentPath(os.PathLike):  # noqa : F811
                 f.close()  # deletes the tmp file, but we can still use its name
                 self.get(f.name)
                 if use_dask:
+                    check_dask()
                     parts = delayed(pd.read_excel)(f.name, **kwargs)
                     data = dd.from_delayed(parts)
                     # We should not delete the tmp file, since dask does its operations lasily.
@@ -1834,6 +1864,8 @@ class TransparentPath(os.PathLike):  # noqa : F811
 
         """
         self.check_multiplicity()
+        if "dask" in str(type(data)):
+            check_dask()
 
         if make_parents and not self.parent.is_dir():
             self.parent.mkdir()
@@ -1853,6 +1885,7 @@ class TransparentPath(os.PathLike):  # noqa : F811
                 data=data, overwrite=overwrite, present=present, update_cache=update_cache, **kwargs,
             )
             if isinstance(data, dd.DataFrame):
+                # noinspection PyUnresolvedReferences
                 assert self.with_suffix("").is_dir(exist=True)
                 return
         elif self.suffix == ".hdf5" or self.suffix == ".h5":
